@@ -52,6 +52,7 @@ daemon code: http://peterlombardo.wikidot.com/linux-daemon-in-c
 #define DAEMON_NAME "[dsk_mgr]"
 #define DEFAULT_XMLRPC_SERVER "http://192.168.0.13/rpc/myserver.php"
 #define TMP_POSITIONS_FILE "/var/tmp/positions.txt"
+#define TMP_DEBUG_FILE "/tmp/phonehome-debug.txt"
 
 GSList* gps_positions = NULL;
 gboolean connection_flag=FALSE;
@@ -88,6 +89,18 @@ void PrintUsage(int argc, char *argv[]) {
   }
 }
 
+void log_debug(gchar *snt){
+  FILE *fh;
+  fh=fopen(TMP_DEBUG_FILE,"a");
+  if(fh==NULL){
+    g_print( "Problem appending to  %s: %s\n", TMP_DEBUG_FILE,strerror( errno ));
+    return;
+  }
+  g_print("debug: %s",snt);
+  fprintf(fh,"%s",snt);
+  fclose(fh);
+}
+
 gboolean use_ssl(){
   if(xmlrpc_server==NULL) {return FALSE;}
   if(g_str_has_prefix(xmlrpc_server,"https")==TRUE){return TRUE;}
@@ -96,13 +109,14 @@ gboolean use_ssl(){
 
 gboolean send_jpeg(unsigned char *data)
 {
-  g_print("send_jpg \n");
+  log_debug("send_jpg \n");
   GdkPixbuf *pixbuf = NULL;
   GError *error = NULL;
   gchar *buffer=NULL;
   gsize *buffer_size=NULL;
   gchar *b_encoded;
   guint height, width, bpp;
+  gchar *debug_snt;
 
   SoupSession*  soup_session;
   SoupXmlrpcMessage *msg;
@@ -114,10 +128,12 @@ gboolean send_jpeg(unsigned char *data)
   if(proxy_mode==CON_IC_PROXY_MODE_NONE) {
     soup_session=soup_session_sync_new();
   } else if (proxy_mode==CON_IC_PROXY_MODE_MANUAL){
-    g_print("using a manual proxy:%s\n",soup_proxy_uri_string);
+    debug_snt=g_strdup_printf("using a manual proxy:%s\n",soup_proxy_uri_string);
+    log_debug(debug_snt);
+    g_free(debug_snt);
     soup_session=soup_session_sync_new_with_options(SOUP_SESSION_PROXY_URI,soup_proxy_uri,NULL);
   } else {
-    g_print("Automatic proxy mode not supported\n");
+    log_debug("Automatic proxy mode not supported\n");
     g_object_unref(soup_session);
     return FALSE;
   }
@@ -145,7 +161,9 @@ gboolean send_jpeg(unsigned char *data)
 
   if(!gdk_pixbuf_save_to_buffer(pixbuf,&buffer,buffer_size,"jpeg",&error,NULL))
     {
-      g_print("Problem saving pic in a buffer:%s\n", error->message);
+      debug_snt=g_strdup_printf("Problem saving pic in a buffer:%s\n", error->message);
+      log_debug(debug_snt);
+      g_free(debug_snt);
       g_error_free(error);
       gdk_pixbuf_unref(pixbuf);
       g_free(buffer_size);
@@ -159,7 +177,10 @@ gboolean send_jpeg(unsigned char *data)
 
   msg = soup_xmlrpc_message_new (uri);
   if (!msg) {
-    g_print("Could not create web service request to '%s'\n", uri);
+
+    debug_snt=g_strdup_printf("Could not create web service request to '%s'\n", uri);
+    log_debug(debug_snt);
+    g_free(debug_snt);
     gdk_pixbuf_unref(pixbuf);
     g_free(buffer);
     g_free(buffer_size);
@@ -187,11 +208,12 @@ gboolean send_jpeg(unsigned char *data)
   soup_xmlrpc_message_persist (msg);
   rpc_status=soup_session_send_message(soup_session, SOUP_MESSAGE(msg));
 
+  debug_snt=g_strdup_printf("rpc_status=%i\n",rpc_status);
+  log_debug(debug_snt);
+  g_free(debug_snt);
 
-  g_print("rpc_status=%i\n",rpc_status);
-  g_print("a\n");
   if(rpc_status!=200){
-    g_print("Problem with XMLRPC communication\n");
+    log_debug("Problem with XMLRPC communication\n");
     gdk_pixbuf_unref(pixbuf);
     g_free(buffer);
     g_free(buffer_size);
@@ -201,10 +223,10 @@ gboolean send_jpeg(unsigned char *data)
     g_object_unref(soup_session);
     return FALSE;
   }
-  g_print("b\n");
+
   rpc_response=soup_xmlrpc_message_parse_response (SOUP_XMLRPC_MESSAGE (msg));
   if (!rpc_response) {
-    g_print("Could not parse XMLRPC response\n");
+    log_debug("Could not parse XMLRPC response\n");
     gdk_pixbuf_unref(pixbuf);
     g_free(buffer);
     g_free(buffer_size);
@@ -215,10 +237,10 @@ gboolean send_jpeg(unsigned char *data)
     return FALSE;
   }
 
-  g_print("c\n");
+
   value = soup_xmlrpc_response_get_value (rpc_response);
   if (!value) {
-    g_print("No response value in XMLRPC response\n");
+    log_debug("No response value in XMLRPC response\n");
     gdk_pixbuf_unref(pixbuf);
     g_free(buffer);
     g_free(buffer_size);
@@ -231,20 +253,19 @@ gboolean send_jpeg(unsigned char *data)
 
   gboolean *bo;
   bo=g_malloc(sizeof(gboolean));
-  g_print("type=%i\n",soup_xmlrpc_value_get_type (value));
-
+  debug_snt=g_strdup_printf("type=%i\n",soup_xmlrpc_value_get_type (value));
+  log_debug(debug_snt);
+  g_free(debug_snt);
  
   if(!soup_xmlrpc_value_get_boolean(value,bo)){
-    g_print("not able to get the boolean\n");
-  }
-  g_print("d\n");
-  if(*bo==TRUE){
-    g_print("Send pic:OK\n");
-  } else {
-    g_print("Sending pic: FAILED\n");
+    log_debug("not able to get the boolean\n");
   }
 
-  g_print("e\n");
+  if(*bo==TRUE){
+    log_debug("Send pic:OK\n");
+  } else {
+    log_debug("Sending pic: FAILED\n");
+  }
 
   /* Free allocated resources and return TRUE which means
    * that the operation was succesful */
@@ -264,19 +285,18 @@ gboolean send_jpeg(unsigned char *data)
  * a message */
 static gboolean bus_callback(GstBus *bus, GstMessage *message, gpointer *appdata)
 {
-  //g_print("Gst pipeline bus_callback\n");
   gchar *message_str;
-  //const gchar *message_name;
+  gchar *debug_snt;
 
   GError *error;
-  //g_print ("Got %s message\n", GST_MESSAGE_TYPE_NAME (message));
-  //g_print("message_type=%i\n",GST_MESSAGE_TYPE(message));
     
   /* Report errors to the console */
   if(GST_MESSAGE_TYPE(message) == GST_MESSAGE_ERROR)
     {
       gst_message_parse_error(message, &error, &message_str);
-      g_error("GST error: %s\n", message_str);
+      debug_snt=g_strdup_printf("GST error: %s\n", message_str);
+      log_debug(debug_snt);
+      g_free(debug_snt);
       g_free(error);
       g_free(message_str);
     }
@@ -285,30 +305,16 @@ static gboolean bus_callback(GstBus *bus, GstMessage *message, gpointer *appdata
   if(GST_MESSAGE_TYPE(message) == GST_MESSAGE_WARNING)
     {
       gst_message_parse_warning(message, &error, &message_str);
-      g_warning("GST warning: %s\n", message_str);
+      debug_snt=g_strdup_printf("GST warning: %s\n", message_str);
+      log_debug(debug_snt);
+      g_free(debug_snt);
       g_free(error);
       g_free(message_str);
     }
-  /*
-  if(GST_MESSAGE_TYPE(message)==GST_MESSAGE_STATE_CHANGED){
-    //g_print("state changed\n");
-    GstState *oldstate;
-    GstState *newstate;
-    GstState *pendingstate;
-    gst_message_parse_state_changed     (message,
-					 oldstate,
-					 newstate,
-					 pendingstate);
-    
-    //g_print("old=%i new=%i pending=%i\n",*oldstate,*newstate,*pendingstate);
-    //g_free(oldstate);
-    //g_free(newstate);
-    //g_free(pendingstate);
-  }
-  */
+
   if(GST_MESSAGE_TYPE(message) == GST_MESSAGE_EOS)
     {
-      g_print("end of stream\n");
+      log_debug("end of stream\n");
       gst_element_set_state(pipeline, GST_STATE_NULL);
       gst_object_unref(GST_OBJECT (pipeline));
     }
@@ -324,7 +330,7 @@ gboolean create_pipe(){
   GstElement *csp_filter, *image_filter;
   GstBus *bus;
   GstCaps *caps;
- 
+
   pipeline = gst_pipeline_new("test-camera");
 
   bus = gst_pipeline_get_bus(GST_PIPELINE(pipeline));
@@ -340,7 +346,7 @@ gboolean create_pipe(){
   if(!(pipeline && camera_src && csp_filter 
        && image_queue && image_filter && image_sink))
     {
-      g_critical("Couldn't create pipeline elements");
+      log_debug("Couldn't create pipeline elements\n");
       return FALSE;
     }
 
@@ -384,17 +390,20 @@ gboolean create_pipe(){
 }
 
 void save_positions_to_file(){
-  g_print("Saving stuff to file\n");
+  log_debug("Saving stuff to file\n");
   FILE * fh;
+  gchar *debug_snt;
   GSList* new_head = gps_positions;
 
   fh=fopen(TMP_POSITIONS_FILE, "a");
   if(fh==NULL){
-    g_print("Problem appending to a file\n");
+    debug_snt=g_strdup_printf("Problem appending to  %s: %s\n", TMP_POSITIONS_FILE,strerror( errno ) );
+    log_debug(debug_snt);
+    g_free(debug_snt);
     return;
   }
 
-  if (new_head==NULL) {g_print("New_head is NULL\n");}
+  if (new_head==NULL) {log_debug("New_head is NULL\n");}
   while (new_head != NULL){
     GSList * next_head=g_slist_next(new_head);
     gps_info * cur_info=new_head->data;
@@ -407,13 +416,16 @@ void save_positions_to_file(){
 }
 
 void load_positions_from_file(){
-  g_print("Loading data from file\n");
+  log_debug("Loading data from file...\n");
   FILE * fh;
+  gchar *debug_snt;
   char line [128];
 
   fh=fopen(TMP_POSITIONS_FILE, "r");
   if(fh==NULL){
-    g_print("Problem reading file\n");
+    debug_snt=g_strdup_printf("Problem reading %s: %s\n", TMP_POSITIONS_FILE,strerror( errno ) );
+    log_debug(debug_snt);
+    g_free(debug_snt);
     return;
   }
   
@@ -424,7 +436,9 @@ void load_positions_from_file(){
     int nbr_match;
     nbr_match=sscanf(line,"%f:%f:%u",&lat,&lon,&date);
     if(nbr_match!=3){
-      g_print("Problem scanning:%s\n",line);
+      debug_snt=g_strdup_printf("Problem scanning:%s\n",line);
+      log_debug(debug_snt);
+      g_free(debug_snt);
       continue;
     }
 
@@ -437,12 +451,22 @@ void load_positions_from_file(){
     gps_positions=g_slist_prepend(gps_positions,(gpointer) cur_info);
   }
   fclose(fh);
-  remove(TMP_POSITIONS_FILE);
+
+  if(unlink(TMP_POSITIONS_FILE)!=0){
+    debug_snt=g_strdup_printf("Error removing file %s: %s\n",TMP_POSITIONS_FILE, strerror( errno ) );
+    log_debug(debug_snt);
+    g_free(debug_snt);
+
+  } else {
+    debug_snt=g_strdup_printf("Removed %s\n",TMP_POSITIONS_FILE);
+    log_debug(debug_snt);
+    g_free(debug_snt);
+  }
 }
 
 
 int free_stuff_and_die(){
-  g_print("free_stuff_and_die\n");
+  log_debug("free_stuff_and_die\n");
   save_positions_to_file();
   g_free(xmlrpc_id);
   g_free(xmlrpc_password);
@@ -567,32 +591,41 @@ int daemonize(int argc, char *argv[]){
 
 static void show_locations(gpointer gps_data, gpointer user_data){
   gps_info *loc;
+  gchar * debug_snt;
   loc=(gps_info *) gps_data;
   //const time_t tmp=time(NULL);
   const time_t tmp=loc->date;
-  g_print("lat=%f lon=%f time=%s",loc->lat,loc->lon,ctime(&tmp));
-  //g_print("next=%i\n", g_slist_next(loc));
+  debug_snt=g_strdup_printf("lat=%f lon=%f time=%s",loc->lat,loc->lon,ctime(&tmp));
+  log_debug(debug_snt);
+  g_free(debug_snt);
 }
 
 void gconf_key_changed_callback(GConfClient* gconf_client,
 				guint cnxn_id,
 				GConfEntry *entry,
 				gpointer user_data){
-  g_print("gconf key=%s has changed\n",entry->key);
+  gchar *debug_snt;
+  debug_snt=g_strdup_printf("gconf key=%s has changed\n",entry->key);
+  log_debug(debug_snt);
+  g_free(debug_snt);
 
   if(strcmp(entry->key,"/apps/osso/phonehome/id")==0 && entry->value!=NULL){
     if(entry->value->type == GCONF_VALUE_STRING){
-    g_print("Changing id with %s\n", gconf_value_get_string(entry->value));
-    g_free(xmlrpc_id);
-    xmlrpc_id=gconf_client_get_string(gconf_client, "/apps/osso/phonehome/id",
-				      NULL);
+      debug_snt=g_strdup_printf("Changing id with %s\n", gconf_value_get_string(entry->value));
+      log_debug(debug_snt);
+      g_free(debug_snt);
+      g_free(xmlrpc_id);
+      xmlrpc_id=gconf_client_get_string(gconf_client, "/apps/osso/phonehome/id",
+					NULL);
     }
   }
   
   
   if(strcmp(entry->key,"/apps/osso/phonehome/password")==0 && entry->value!=NULL){
     if(entry->value->type == GCONF_VALUE_STRING){
-      g_print("Changing password with %s\n", gconf_value_get_string(entry->value));
+      debug_snt=g_strdup_printf("Changing password with %s\n", gconf_value_get_string(entry->value));
+      log_debug(debug_snt);
+      g_free(debug_snt);
       g_free(xmlrpc_password);
       xmlrpc_password=gconf_client_get_string(gconf_client, "/apps/osso/phonehome/password",
 				      NULL);
@@ -601,7 +634,9 @@ void gconf_key_changed_callback(GConfClient* gconf_client,
   
   if(strcmp(entry->key,"/apps/osso/phonehome/server")==0 && entry->value!=NULL){
     if(entry->value->type == GCONF_VALUE_STRING){
-      g_print("Changing server with %s\n", gconf_value_get_string(entry->value));
+      debug_snt=g_strdup_printf("Changing server with %s\n", gconf_value_get_string(entry->value));
+      log_debug(debug_snt);
+      g_free(debug_snt);
       g_free(xmlrpc_server);
       xmlrpc_server=gconf_client_get_string(gconf_client, "/apps/osso/phonehome/server",
 				      NULL);
@@ -618,29 +653,22 @@ static gboolean buffer_probe_callback(
 				      GstElement *image_sink,
 				      GstBuffer *buffer, GstPad *pad, gpointer *appdata){
 
-  g_print("buffer_probe_callback\n");
+  log_debug("buffer_probe_callback\n");
   unsigned char *data_photo =    (unsigned char *) GST_BUFFER_DATA(buffer);
   if(!send_jpeg(data_photo))
-    g_print("photo-failed\n");
+    log_debug("photo-failed\n");
   else
-    g_print("photo-taken\n");
+    log_debug("photo-taken\n");
 
-  //GstElement  *camera_src;
-  //camera_src = gst_bin_get_by_name(GST_BIN(pipeline),"camera_src");
-  //GstEvent* eos_event;
-  //eos_event= gst_event_new_eos ();
-  //gst_element_send_event (camera_src,eos_event);
   g_signal_handler_disconnect(G_OBJECT(image_sink),
 			      buffer_cb_id);
 
-  //gst_element_set_state(pipeline, GST_STATE_NULL);
-  //gst_object_unref(GST_OBJECT (pipeline));
   return TRUE;
 }
 
 
 gboolean stop_cam(gpointer data){
-  g_print("Stopping cam\n");
+  log_debug("Stopping cam\n");
   gst_element_set_state(pipeline, GST_STATE_NULL);
   gst_object_unref(GST_OBJECT (pipeline));
   cam_in_action_flag=FALSE;
@@ -648,9 +676,9 @@ gboolean stop_cam(gpointer data){
 }
 
 void take_photo(){
-  g_print("Trying to get a pic\n");
+  log_debug("Trying to get a pic\n");
   if(cam_in_action_flag==TRUE) {
-    g_print("Cam already in action\n");
+    log_debug("Cam already in action\n");
     return;
   }
 
@@ -670,23 +698,23 @@ void take_photo(){
 }
 
 void send_gps_infos(){
-  g_print("send gps info\n");
+  log_debug("send gps info\n");
   load_positions_from_file();
   GSList* new_head = gps_positions;
   SoupSession*  soup_session;
-
-  
+  gchar *debug_snt;
   char *uri = xmlrpc_server;
-  //soup_session=soup_session_sync_new_with_options(SOUP_SESSION_MAX_CONNS,5);
-  //soup_session=soup_session_sync_new();
+
   if(proxy_mode==CON_IC_PROXY_MODE_NONE) {
-    g_print("no proxy\n");
+    log_debug("no proxy\n");
     soup_session=soup_session_sync_new();
   } else if (proxy_mode==CON_IC_PROXY_MODE_MANUAL){
-    g_print("using a manual proxy:%s\n",soup_proxy_uri_string);
+    debug_snt=g_strdup_printf("using a manual proxy:%s\n",soup_proxy_uri_string);
+    log_debug(debug_snt);
+    g_free(debug_snt);
     soup_session=soup_session_sync_new_with_options(SOUP_SESSION_PROXY_URI,soup_proxy_uri,NULL);
   } else {
-    g_print("Automatic proxy mode not supported\n");
+    log_debug("Automatic proxy mode not supported\n");
     return;
   }
 
@@ -700,11 +728,15 @@ void send_gps_infos(){
       GSList * next_head=g_slist_next(new_head);
       gps_info * cur_info=new_head->data;
       const time_t tmp_date=cur_info->date;
-      g_print("CA: lat=%f lon=%f time=%s",cur_info->lat,cur_info->lon,ctime(&tmp_date));
+      debug_snt=g_strdup_printf("CA: lat=%f lon=%f time=%s",cur_info->lat,cur_info->lon,ctime(&tmp_date));
+      log_debug(debug_snt);
+      g_free(debug_snt);
 
       msg = soup_xmlrpc_message_new (uri);
       if (!msg) {
-	g_print("Could not create web service request to '%s'\n", uri);
+	debug_snt=g_strdup_printf("Could not create web service request to '%s'\n", uri);
+	log_debug(debug_snt);
+	g_free(debug_snt);
 	g_object_unref(soup_session);
 	break;
       }
@@ -734,9 +766,12 @@ void send_gps_infos(){
       soup_xmlrpc_message_persist (msg);
       rpc_status=soup_session_send_message(soup_session, SOUP_MESSAGE(msg));
 
-      g_print("rpc_status=%i\n",rpc_status);
+      debug_snt=g_strdup_printf("rpc_status=%i\n",rpc_status);
+      log_debug(debug_snt);
+      g_free(debug_snt);
+
       if(rpc_status!=200){
-	g_print("Problem with XMLRPC communication\n");
+	log_debug("Problem with XMLRPC communication\n");
 	g_object_unref(msg);
 	g_object_unref(soup_session);
 	break;
@@ -745,7 +780,7 @@ void send_gps_infos(){
 
       rpc_response=soup_xmlrpc_message_parse_response (SOUP_XMLRPC_MESSAGE (msg));
       if (!rpc_response) {
-	g_print("Could not parse XMLRPC response\n");
+	log_debug("Could not parse XMLRPC response\n");
 	g_object_unref(msg);
 	g_object_unref(soup_session);
 	break;
@@ -754,7 +789,7 @@ void send_gps_infos(){
 
       value = soup_xmlrpc_response_get_value (rpc_response);
       if (!value) {
-	g_print("No response value in XMLRPC response\n");
+	log_debug("No response value in XMLRPC response\n");
 	g_object_unref(msg);
 	g_object_unref(rpc_response);
 	g_object_unref(soup_session);
@@ -769,17 +804,13 @@ void send_gps_infos(){
 
 
       if(*b==TRUE){
-	g_print("OK\n");
 	gps_positions=g_slist_remove(gps_positions, cur_info);
 	g_free(cur_info);
       } else {
-	g_print("Insert failed for some reasons\n");
+	log_debug("Insert failed for some reasons\n");
       }
       g_free(b);
       g_object_unref (rpc_response);
-      //g_print("___\n");
-      //g_slist_foreach(gps_positions, show_locations, NULL);
-      //g_print("___\n");
       new_head=next_head;
       g_object_unref(msg);
 
@@ -791,16 +822,21 @@ void send_gps_infos(){
 gboolean test_xmlrpc_login(){
   SoupSession*  soup_session;
   char *uri = xmlrpc_server;
-  g_print("testing login\n");
-  g_print("proxy_mode=%i\n",proxy_mode);
-  //soup_session=soup_session_sync_new_with_options(SOUP_SESSION_MAX_CONNS,5);
+  gchar *debug_snt;
+  log_debug("testing login\n");
+  debug_snt=g_strdup_printf("proxy_mode=%i\n",proxy_mode);
+  log_debug(debug_snt);
+  g_free(debug_snt);
+
   if(proxy_mode==CON_IC_PROXY_MODE_NONE) {
     soup_session=soup_session_sync_new();
   } else if (proxy_mode==CON_IC_PROXY_MODE_MANUAL){
-    g_print("using a manual proxy:%s\n",soup_proxy_uri_string);
+    debug_snt=g_strdup_printf("using a manual proxy:%s\n",soup_proxy_uri_string);
+    log_debug(debug_snt);
+    g_free(debug_snt);
     soup_session=soup_session_sync_new_with_options(SOUP_SESSION_PROXY_URI,soup_proxy_uri,NULL);
   } else {
-    g_print("Automatic proxy mode not supported\n");
+    log_debug("Automatic proxy mode not supported\n");
     return FALSE;
   }
 
@@ -810,7 +846,9 @@ gboolean test_xmlrpc_login(){
   SoupXmlrpcValue *value;
   msg = soup_xmlrpc_message_new (uri);
   if (!msg) {
-    g_print("Could not create web service request to '%s'\n", uri);
+    debug_snt=g_strdup_printf("Could not create web service request to '%s'\n", uri);
+    log_debug(debug_snt);
+    g_free(debug_snt);
     return FALSE;
   }
   soup_xmlrpc_message_start_call(msg,"test_login");
@@ -826,16 +864,15 @@ gboolean test_xmlrpc_login(){
   soup_xmlrpc_message_persist (msg);
   rpc_status=soup_session_send_message(soup_session, SOUP_MESSAGE(msg));
 
-  g_print("rpc_status=%i\n",rpc_status);
   if(rpc_status!=200){
-    g_print("Problem with XMLRPC communication\n");
+    log_debug("Problem with XMLRPC communication\n");
     g_object_unref(soup_session);
     return FALSE;
   }
 
   rpc_response=soup_xmlrpc_message_parse_response (SOUP_XMLRPC_MESSAGE (msg));
   if (!rpc_response) {
-    g_print("Could not parse XMLRPC response\n");
+    log_debug("Could not parse XMLRPC response\n");
     g_object_unref(msg);
     g_object_unref(soup_session);
     return FALSE;
@@ -843,9 +880,10 @@ gboolean test_xmlrpc_login(){
 
   value = soup_xmlrpc_response_get_value (rpc_response);
   if (!value) {
-    g_print("No response value in XMLRPC response\n");
+    log_debug("No response value in XMLRPC response\n");
     g_object_unref(msg);
     g_object_unref(soup_session);
+    g_object_unref(rpc_response);
     return FALSE;
   }
   
@@ -853,14 +891,15 @@ gboolean test_xmlrpc_login(){
   b=g_malloc(sizeof(gboolean));
   soup_xmlrpc_value_get_boolean(value,b);
   g_object_unref(msg);
+  g_object_unref(rpc_response);
 
   if(*b==TRUE){
-    g_print("OK\n");
+    log_debug("Login OK\n");
     g_object_unref(soup_session);
     g_free(b);
     return TRUE;
   } else {
-    g_print("NOPE\n");
+    log_debug("Login NOT OK\n");
     g_object_unref(soup_session);
     g_free(b);
     return FALSE;
@@ -870,9 +909,9 @@ gboolean test_xmlrpc_login(){
 }
 
 void connection_available(){
-  g_print("connection available !\n");
+  log_debug("connection available !\n");
   if (test_xmlrpc_login()!=TRUE){
-    g_print("xmlrpc connexion not successfull\n");
+    log_debug("xmlrpc connexion not successfull\n");
     return;
   }
   send_gps_infos();
@@ -890,22 +929,38 @@ static void connection_event_changed(ConIcConnection *connection,
 
   const gchar *iap_id = con_ic_event_get_iap_id(CON_IC_EVENT(event));
   const gchar *bearer = con_ic_event_get_bearer_type(CON_IC_EVENT(event));
+  gchar * debug_snt;
+
+  debug_snt=g_strdup_printf("status=%i\n",status);
+  log_debug(debug_snt);
+  g_free(debug_snt);
 
-  g_print("status=%i\n",status);
   switch(status) {
 
   case CON_IC_STATUS_CONNECTED:
     proxy_mode=con_ic_connection_get_proxy_mode(connection);
-    
-    g_print("Hey, we are connected to IAP %s with bearer %s!\n", iap_id, bearer);
-    g_print("proxy_mode=%i\n",proxy_mode);
+
+    debug_snt=g_strdup_printf("Connected to IAP %s with bearer %s!\n", iap_id, bearer);
+    log_debug(debug_snt);
+    g_free(debug_snt);
+
+    debug_snt=g_strdup_printf("proxy_mode=%i\n",proxy_mode);
+    log_debug(debug_snt);
+    g_free(debug_snt);
+
     if( proxy_mode==CON_IC_PROXY_MODE_MANUAL) {
       const gchar* host=con_ic_connection_get_proxy_host(connection,CON_IC_PROXY_PROTOCOL_HTTP);
       const gchar* host_ssl=con_ic_connection_get_proxy_host(connection,CON_IC_PROXY_PROTOCOL_HTTPS);
 
-      g_print("manual proxy mode\n");
-      g_print("proxy=%s\n",host);
-      g_print("ssl proxy=%s\n",host_ssl);
+      log_debug("manual proxy mode\n");
+
+      debug_snt=g_strdup_printf("proxy=%s\n",host);
+      log_debug(debug_snt);
+      g_free(debug_snt);
+
+      debug_snt=g_strdup_printf("ssl proxy=%s\n",host_ssl);
+      log_debug(debug_snt);
+      g_free(debug_snt);
 
       http_proxy_port=con_ic_connection_get_proxy_port(connection,CON_IC_PROXY_PROTOCOL_HTTP);
       https_proxy_port=con_ic_connection_get_proxy_port(connection,CON_IC_PROXY_PROTOCOL_HTTPS);
@@ -947,7 +1002,7 @@ static void connection_event_changed(ConIcConnection *connection,
 
     }
     if( proxy_mode==CON_IC_PROXY_MODE_AUTO) {
-      g_print("automatic proxy mode not supported\n");
+      log_debug("automatic proxy mode not supported\n");
       return;
     }
     
@@ -956,33 +1011,38 @@ static void connection_event_changed(ConIcConnection *connection,
     connection_available();
     break;
   case CON_IC_STATUS_DISCONNECTED:
-    g_print("We are disconnected...");
+    log_debug("We are disconnected...");
     connection_flag=FALSE;
     break;
   default:
-    g_debug("Unknown connection status received");
+    log_debug("Unknown connection status received");
   }
 
 
-  g_print("Network connection changed\n");
+  log_debug("Network connection changed\n");
 }
 
 static void
 location_changed (LocationGPSDevice *device, gpointer gps_data)
 {
-  //GSList * gps_locations = (GSList *) gps_data;
   static time_t last_gps_fix=0;
   time_t now;
+  gchar * debug_snt;
+
   now=time(NULL);
+
+  //no more than one fix per minute recorded.
   if(last_gps_fix!=0 && difftime(now,last_gps_fix)<60){
-    g_print("Last gpx fix too recent, not including this fix\n");
     return;
   }
+
   last_gps_fix=time(NULL);
   gps_info *cur_info;
 
-  g_print ("Latitude: %.2f\nLongitude: %.2f\nAltitude: %.2f\n",
+  debug_snt=g_strdup_printf("Latitude: %.2f\nLongitude: %.2f\nAltitude: %.2f\n",
 	   device->fix->latitude, device->fix->longitude, device->fix->altitude);
+  log_debug(debug_snt);
+  g_free(debug_snt);
 
   cur_info=g_malloc(sizeof(gps_info));
   cur_info->lat=device->fix->latitude;
@@ -995,26 +1055,30 @@ location_changed (LocationGPSDevice *device, gpointer gps_data)
 
 gboolean my_timeout(gpointer loop) {
   //static double cnt=1;
-  g_print("my timeout\n");
-  g_print("id=%s password=%s server=%s\n",xmlrpc_id,xmlrpc_password,xmlrpc_server);
+  log_debug("my timeout\n");
   
   //GMainLoop *mloop=(GMainLoop *) loop;
 
 
   if(test_xmlrpc_login()==TRUE) {
-    g_print("login ok\n");
+    log_debug("login ok\n");
   }else{
-    g_print("login not ok\n");
+    log_debug("login not ok\n");
   }
-  g_print("goodbye\n");
+  log_debug("goodbye\n");
   g_main_loop_quit (loop);
   //return FALSE;
   return TRUE;
 }
 
+gboolean idle_timeout(gpointer data){
+  //log_debug("nothing to do\n");
+  sleep(1);
+  return TRUE;
+}
+
 gboolean monitor_connection(gpointer user_data){
-  g_print("Monitoring cnx\n");
-  g_print("flag:%i\n",connection_flag);
+  log_debug("Monitoring cnx\n");
   if(connection_flag==TRUE) {
       connection_available();
   }
@@ -1024,7 +1088,10 @@ gboolean monitor_connection(gpointer user_data){
 void fill_gps_positions_with_fake(){
   int i;
   for(i=0;i<5;i++){
-    g_print("i=%i\n",i);
+    gchar *debug_snt=NULL;
+    debug_snt=g_strdup_printf("i=%i\n",i);
+    log_debug(debug_snt);
+    g_free(debug_snt);
     gps_info * tmp_gps_info;
     tmp_gps_info=g_malloc(sizeof(gps_info));
     tmp_gps_info->lat=i;
@@ -1037,20 +1104,20 @@ void fill_gps_positions_with_fake(){
 }
 
 void  device_state_changed(osso_hw_state_t *state, gpointer data){
-  g_print("device state changed \n");
+  log_debug("device state changed \n");
   
   if (state->shutdown_ind==TRUE) {
-    g_print("Shutdown on its way\n");
+    log_debug("Shutdown on its way\n");
     save_positions_to_file();
   }
 
   if (state->memory_low_ind==TRUE) {
-    g_print("Low memory\n");
+    log_debug("Low memory\n");
 
   }
 
   if (state->save_unsaved_data_ind==TRUE) {
-    g_print("Need to save data\n");
+    log_debug("Need to save data\n");
     save_positions_to_file();
   }
 
@@ -1060,7 +1127,7 @@ void  device_state_changed(osso_hw_state_t *state, gpointer data){
 
 gboolean init_gstreamer_stuff(int * argc, char **argv[]){
   //https://garage.maemo.org/svn/maemoexamples/tags/maemo_4.1/maemo-examples/example_camera.c
-  g_print("init g_streamer\n");
+  log_debug("init g_streamer\n");
   gst_init(argc, argv); 
   return TRUE;
 }
@@ -1075,15 +1142,15 @@ int main(int argc, char *argv[]) {
   LocationGPSDevice *gps_device;
   GConfClient* gconf_client;
   GError* err;
-
+  gchar * debug_snt;
   
-  osso_context=osso_initialize  (  "phonehome",
+  osso_context=osso_initialize  (  "org.maemo.phonehome",
 				   "1.0",
 				   TRUE,
 				   NULL
 				   );
   if(osso_context==NULL) {
-    g_print("Unable to create an osso context, exiting\n");
+    log_debug("Unable to create an osso context, exiting\n");
     exit(1);
   }
 
@@ -1098,15 +1165,8 @@ int main(int argc, char *argv[]) {
   g_type_init();
   g_thread_init (NULL);
 
-
-
-
   gconf_init(argc, argv, &err);
-  //g_print("Pb with gconf: %s\n",err->message);
-  //g_error_free(err);
-
   gconf_client=gconf_client_get_default ();
-
   xmlrpc_id=gconf_client_get_string(gconf_client, "/apps/osso/phonehome/id",
 			  NULL);
   xmlrpc_password=gconf_client_get_string(gconf_client, "/apps/osso/phonehome/password",
@@ -1118,28 +1178,19 @@ int main(int argc, char *argv[]) {
     xmlrpc_server=DEFAULT_XMLRPC_SERVER;
   }
 
-  g_print("%s:%s\n",xmlrpc_id,xmlrpc_password);
-
-
-  /*
-  if(xmlrpc_id==NULL||xmlrpc_password==NULL){
-    g_print("Set password and id with gconftool-2 first\n");
-    g_print("gconftool-2 -t string -s '/apps/osso/phonehome/id' 'your_user_id'\n");
-    g_print("gconftool-2 -t string -s '/apps/osso/phonehome/password' 'your_password'\n");
-    g_print("gconftool-2 -t string -s '/apps/osso/phonehome/server' 'https://aserver/xmlrcp.php'\n");
-    
-    exit(1);
-  }
-  */
-  g_print("xmlr_rpc_server=%s\n",xmlrpc_server);
   
-  g_print("test gst:%i\n",init_gstreamer_stuff(&argc,&argv));
+  debug_snt=g_strdup_printf("xmlr_rpc_server=%s\n",xmlrpc_server);
+  log_debug(debug_snt);
+  g_free(debug_snt);
+  debug_snt=g_strdup_printf("init_gstreamer_stuff:%i\n",init_gstreamer_stuff(&argc,&argv));
+  log_debug(debug_snt);
+  g_free(debug_snt);
 
   //Main loop 
   mainloop = g_main_loop_new(NULL, FALSE);
   if (mainloop == NULL) {
     /* Print error and terminate. */
-    g_print("Couldn't create GMainLoop");
+    log_debug("Couldn't create GMainLoop");
     exit(EXIT_FAILURE);
   }  
 
@@ -1168,7 +1219,9 @@ int main(int argc, char *argv[]) {
 
   //g_timeout_add(5000,my_timeout,(gpointer) mainloop);
   g_timeout_add(5*60*1000,monitor_connection,NULL);
+  g_idle_add(idle_timeout,NULL);
   //fill_gps_positions_with_fake();
+  //log_debug("coin coin\n");
   //send_gps_infos();  
   //save_positions_to_file();
 
